#
# This file is part of pysimpledb.
#
# pysimpledb is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# pysimpledb is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with pysimpledb.  If not, see <http://www.gnu.org/licenses/>.
#
#      Author Daniel Mikusa <dan@mikusa.com>
#   Copyright Daniel Mikusa 2008
#

class AbstractParameterProvider(object):
    def provide(self):
        raise NotImplementedError("You cannot use this class directly")

class DictionaryParameterProvider(AbstractParameterProvider):
    """
    Provides parameters by sending the data in a dictionary

    This is compatible with named parameters.
    """
    def __init__(self, data):
        self.data = data

    def provide(self):
        return self.data.values()

class ListParameterProvider(AbstractParameterProvider):
    """
    Provides parameters by sending the data in a list

    This is compatible with value parameters.
    """
    def __init__(self, data):
        self.data = data

    def provide(self):
        return self.data

class ObjectParameterProvider(AbstractParameterProvider):
    """
    Provides parameters by sending all of the objects properties

    This is compatible with named parameters.
    """
    def __init__(self, data):
        self.data = data

    def provide(self):
        return self.data.__dict__

class FilteredObjectParameterProvider(AbstractParameterProvider):
    """
    Provides parameters by sending a filtered dictionary of properties

    This is compatible with named parameters.
    """
    def __init__(self, data, filter):
        self.data = data
        self.filter = filter

    def provide(self):
        tmp = {}
        for col,value in self.data.__dict__.iteritems():
            if self.filter(col):
                tmp[col] = value
        return tmp
